<?php
namespace PME\Modules\Planejamento\Cadastro\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;

class UnidadeMedidaController {

	protected $connection;
    protected $environment;

    public function __construct($connection, $environment) {
    	$this->connection = $connection;
        $this->environment = $environment;
	}

	public function save(DTO\Request $request, DTO\Response $response) {
        try{
            $this->connection->beginTransaction();
            $row = $request->getRow();
            $nrorg = $this->environment->getNrOrg();
            
            if ($row['OPCRELACAO'] == 1)  $valor = 1/$row['VRFTCONVER'];
            else $valor = $row['VRFTCONVER'];

            $query = "INSERT INTO CONVUNID (SGUNIDDE, SGUNIDPARA, VRFTCONVER, IDTIPOPE, NRORG) VALUES (:SGUNIDDE, :SGUNIDPARA, :VRFTCONVER, :IDTIPOPE, :NRORG)";
            $params = array(
                "SGUNIDDE"   => $row["SGUNIDDE"],
                "SGUNIDPARA" => $row["SGUNIDPARA"]["SGUNIDADE"],
                "VRFTCONVER" => $valor,
                "IDTIPOPE"   => $row["IDTIPOPE"],
                "NRORG"      => $nrorg
            );
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
            $this->connection->commit();
            $response->addDataSet(new DataSet("save", array(true)));
        } catch (\Exception $e) {
            $this->connection->rollback();
            $response->setError(new Error($e->getMessage(), 500));
        }
	}

    public function delete(DTO\Request $request, DTO\Response $response) {
        try {
          $parameters = $request->getParameters();
          $rows = $parameters['checkedRows'];
          $this->connection->beginTransaction();
    
          $query = "DELETE FROM CONVUNID WHERE SGUNIDDE = :SGUNIDDE AND SGUNIDPARA = :SGUNIDPARA AND VRFTCONVER = :VRFTCONVER";
            
          foreach($rows as $row){
            $params = array(
              'SGUNIDDE'   => $row['SGUNIDDE'],
              'SGUNIDPARA' => $row['SGUNIDPARA'],
              'VRFTCONVER' => $row['VRFTCONVER'],
            );
          }
          $this->connection->prepare($query)->execute($params);
          $this->connection->commit();
          $response->addDataSet(new DataSet("success", array(true)));
        } catch (\Exception $e) {
            $this->connection->rollback();
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
}